import"../chunks/DsnmJJEf.js";import{e as E,j as c,s as k,m as e,h as a,v as L,a as z,g as l,r as t}from"../chunks/BZ0BXH4m.js";import{d as M}from"../chunks/fIP5WTNy.js";import{s as u}from"../chunks/C5ruyaoV.js";import{s as y}from"../chunks/BQ1deccM.js";import{s as P}from"../chunks/DQIR6haY.js";import"../chunks/VtU4lcDG.js";const S="/_app/immutable/assets/zen_garden_small.Bbfqs-kl.png",q="data:image/svg+xml,%3csvg%20xmlns='http://www.w3.org/2000/svg'%20width='16'%20height='16'%20fill='currentColor'%20class='bi%20bi-x'%20viewBox='0%200%2016%2016'%3e%3cpath%20d='M4.646%204.646a.5.5%200%200%201%20.708%200L8%207.293l2.646-2.647a.5.5%200%200%201%20.708.708L8.707%208l2.647%202.646a.5.5%200%200%201-.708.708L8%208.707l-2.646%202.647a.5.5%200%200%201-.708-.708L7.293%208%204.646%205.354a.5.5%200%200%201%200-.708'/%3e%3c/svg%3e";var N=(r,s)=>c(s,!l(s)),A=(r,s)=>c(s,!l(s)),D=(r,s)=>c(s,!l(s)),F=(r,s)=>c(s,!l(s)),G=E('<div class="d-flex justify-content-center"><div class="menu mt-5 svelte-1640grj"><button class="quarter active quarter1 svelte-1640grj"><p class="content svelte-1640grj">The Transition Pathway</p></button> <button class="quarter active quarter2 svelte-1640grj"><p class="content svelte-1640grj">The Energy Balance</p></button> <a class="quarter active quarter3 svelte-1640grj" href="/energy_system"><p class="content svelte-1640grj">The Energy System</p></a> <a class="quarter active quarter4 svelte-1640grj" href="/map"><p class="content svelte-1640grj">The Map</p></a> <div class="logo svelte-1640grj"><img alt="The project logo" class="svelte-1640grj"/></div> <div><div class="sublink l1 svelte-1640grj"><a href="./transition/capacity/" class="link-secondary svelte-1640grj">Capacity</a></div> <div class="sublink l2 svelte-1640grj"><a href="./transition/production/" class="link-secondary svelte-1640grj">Production</a></div> <div class="sublink l3 svelte-1640grj"><a href="./transition/emissions/" class="link-secondary svelte-1640grj">Emissions</a></div> <div class="sublink l4 svelte-1640grj"><a href="./transition/costs/" class="link-secondary svelte-1640grj">Costs</a></div> <button type="button" class="close svelte-1640grj" aria-label="Close"><img alt="The project logo" class="svelte-1640grj"/></button></div> <div><div class="sublink l1 svelte-1640grj"><a href="./energy_balance/nodal" class="link-secondary svelte-1640grj">Nodal Energy Balance</a></div> <div class="sublink l2 svelte-1640grj"><a href="./energy_balance/storage" class="link-secondary svelte-1640grj">Storage Energy Balance</a></div> <button type="button" class="close svelte-1640grj" aria-label="Close"><img alt="The project logo" class="svelte-1640grj"/></button></div></div></div>');function U(r){let s="70vh",n=k(!1),o=k(!1);var v=G(),g=e(v);P(g,"",{},{width:s,height:s,"min-width":"320px","min-height":"320px"});var j=e(g);j.__click=[N,n];var h=a(j,2);h.__click=[A,o];var d=a(h,6),w=e(d);t(d);var i=a(d,2);let b;var _=a(e(i),8);_.__click=[D,n];var x=e(_);t(_),t(i);var m=a(i,2);let f;var p=a(e(m),4);p.__click=[F,o];var T=e(p);t(p),t(m),t(g),t(v),L((B,C)=>{u(w,"src",S),b=y(i,1,"links svelte-1640grj",null,b,B),u(x,"src",q),f=y(m,1,"links svelte-1640grj",null,f,C),u(T,"src",q)},[()=>({active:l(n)}),()=>({active:l(o)})]),z(r,v)}M(["click"]);export{U as component};
