import{af as M,D as j,aO as F,q as v,ay as T,aP as V,aI as C,ae as p,ad as m,K as _,L,aQ as S,aR as w,E as U,az as z,aS as K,aT as X,aK as Z,aD as q,aU as G,I as Q,p as B,Z as o,G as J,X as ee,i as te,aV as y,u as ae,W as N,aW as ne,V as se,aX as P,d as A,aY as re,aZ as oe,a_ as ie,a$ as le,b0 as ue,b1 as fe,t as de}from"./BZ0BXH4m.js";import{l as ce}from"./DIeogL5L.js";import{a as _e,r as k,h as g}from"./fIP5WTNy.js";import{c as he}from"./DLtGBQZ4.js";const pe=["touchstart","touchmove"];function ve(e){return pe.includes(e)}let r;function ye(){r=void 0}function xe(e){let t=null,a=v;var i;if(v){for(t=_,r===void 0&&(r=L(document.head));r!==null&&(r.nodeType!==T||r.data!==V);)r=C(r);r===null?p(!1):r=m(C(r))}v||(i=document.head.appendChild(M()));try{j(()=>e(i),F)}finally{a&&(p(!0),r=_,m(t))}}let I=!0;function Ne(e,t){var a=t==null?"":typeof t=="object"?t+"":t;a!==(e.__t??=e.nodeValue)&&(e.__t=a,e.nodeValue=a+"")}function $(e,t){return H(e,t)}function ge(e,t){S(),t.intro=t.intro??!1;const a=t.target,i=v,f=_;try{for(var n=L(a);n&&(n.nodeType!==T||n.data!==V);)n=C(n);if(!n)throw w;p(!0),m(n),U();const s=H(e,{...t,anchor:n});if(_===null||_.nodeType!==T||_.data!==z)throw K(),w;return p(!1),s}catch(s){if(s instanceof Error&&s.message.split(`
`).some(c=>c.startsWith("https://svelte.dev/e/")))throw s;return s!==w&&console.warn("Failed to hydrate: ",s),t.recover===!1&&X(),S(),Z(a),p(!1),$(e,t)}finally{p(i),m(f),ye()}}const h=new Map;function H(e,{target:t,anchor:a,props:i={},events:f,context:n,intro:s=!0}){S();var c=new Set,b=d=>{for(var l=0;l<d.length;l++){var u=d[l];if(!c.has(u)){c.add(u);var R=ve(u);t.addEventListener(u,g,{passive:R});var x=h.get(u);x===void 0?(document.addEventListener(u,g,{passive:R}),h.set(u,1)):h.set(u,x+1)}}};b(q(_e)),k.add(b);var E=void 0,Y=G(()=>{var d=a??t.appendChild(M());return Q(()=>{if(n){B({});var l=o;l.c=n}f&&(i.$$events=f),v&&J(d,null),I=s,E=e(d,i)||{},I=!0,v&&(ee.nodes_end=_),n&&te()}),()=>{for(var l of c){t.removeEventListener(l,g);var u=h.get(l);--u===0?(document.removeEventListener(l,g),h.delete(l)):h.set(l,u)}k.delete(b),d!==a&&d.parentNode?.removeChild(d)}});return D.set(E,Y),E}let D=new WeakMap;function me(e,t){const a=D.get(e);return a?(D.delete(e),a(t)):Promise.resolve()}function be(){return N===null&&ne(),(N.ac??=new AbortController).signal}function W(e){o===null&&y(),ce&&o.l!==null?O(o).m.push(e):ae(()=>{const t=A(e);if(typeof t=="function")return t})}function Ee(e){o===null&&y(),W(()=>()=>A(e))}function we(e,t,{bubbles:a=!1,cancelable:i=!1}={}){return new CustomEvent(e,{detail:t,bubbles:a,cancelable:i})}function Te(){const e=o;return e===null&&y(),(t,a,i)=>{const f=e.s.$$events?.[t];if(f){const n=se(f)?f.slice():[f],s=we(t,a,i);for(const c of n)c.call(e.x,s);return!s.defaultPrevented}return!0}}function Ce(e){o===null&&y(),o.l===null&&P(),O(o).b.push(e)}function Se(e){o===null&&y(),o.l===null&&P(),O(o).a.push(e)}function O(e){var t=e.l;return t.u??={a:[],b:[],m:[]}}const ke=Object.freeze(Object.defineProperty({__proto__:null,afterUpdate:Se,beforeUpdate:Ce,createEventDispatcher:Te,createRawSnippet:he,flushSync:re,getAbortSignal:be,getAllContexts:oe,getContext:ie,hasContext:le,hydrate:ge,mount:$,onDestroy:Ee,onMount:W,setContext:ue,settled:fe,tick:de,unmount:me,untrack:A},Symbol.toStringTag,{value:"Module"}));export{I as a,xe as b,Ee as c,ke as d,ge as h,$ as m,W as o,Ne as s,me as u};
