import"../chunks/DsnmJJEf.js";import{c as t,f as p,a as m,n as s}from"../chunks/BZ0BXH4m.js";import{s as e}from"../chunks/DLtGBQZ4.js";function d(a,n){var o=t(),r=p(o);e(r,()=>n.children??s),m(a,o)}export{d as component};
