function p(n){var i,f,r="";if(typeof n=="string"||typeof n=="number")r+=n;else if(typeof n=="object")if(Array.isArray(n)){var t=n.length;for(i=0;i<t;i++)n[i]&&(f=p(n[i]))&&(r&&(r+=" "),r+=f)}else for(f in n)n[f]&&(r&&(r+=" "),r+=f);return r}function v(){for(var n,i,f=0,r="",t=arguments.length;f<t;f++)(n=arguments[f])&&(i=p(n))&&(r&&(r+=" "),r+=i);return r}function l(n){return typeof n=="object"?v(n):n??""}const c=[...` 	
\r\f \v\uFEFF`];function s(n,i,f){var r=n==null?"":""+n;if(i&&(r=r?r+" "+i:i),f){for(var t in f)if(f[t])r=r?r+" "+t:t;else if(r.length)for(var o=t.length,u=0;(u=r.indexOf(t,u))>=0;){var a=u+o;(u===0||c.includes(r[u-1]))&&(a===r.length||c.includes(r[a]))?r=(u===0?"":r.substring(0,u))+r.substring(a+1):u=a}}return r===""?null:r}function g(n,i=!1){var f=i?" !important;":";",r="";for(var t in n){var o=n[t];o!=null&&o!==""&&(r+=" "+t+": "+o+f)}return r}function e(n,i){if(i){var f="",r,t;return Array.isArray(i)?(r=i[0],t=i[1]):r=i,r&&(f+=g(r)),t&&(f+=g(t,!0)),f=f.trim(),f===""?null:f}return String(n)}export{e as a,l as c,s as t};
