import"./DsnmJJEf.js";import{w as p,p as d,e as h,m,h as u,r as c,v,a as _,i as b}from"./BZ0BXH4m.js";import{s as g}from"./B98B7x2v.js";import{r as x,s as l}from"./C5ruyaoV.js";import{d as k}from"./fIP5WTNy.js";import{a as w}from"./kHklRsBK.js";import{p as f}from"./CUAkeMiK.js";function I(o,t){t.onUpdate?.()}var T=h('<div class="form-check form-switch"><input class="form-check-input" type="checkbox" role="switch"/> <label class="form-check-label"> </label></div>');function A(o,t){p(),d(t,!0);let s=f(t,"value",15),i=f(t,"texts",19,()=>["on","off"]);var a=T(),e=m(a);x(e),e.__change=[I,t];var r=u(e,2),n=m(r,!0);c(r),c(a),v(()=>{l(e,"id",t.formId),l(r,"for",t.formId),g(n,s()?i()[0]:i()[1])}),w(e,s),_(o,a),b()}k(["change"]);export{A as T};
