import"../chunks/DsnmJJEf.js";import"../chunks/69_IOA4Y.js";import{Z as g,_ as b,u as c,d as x,$ as l,a0 as k,g as d,a1 as y,a2 as E,p as Z,e as $,f as j,v as q,a as w,i as z,m as u,r as m,h as A}from"../chunks/BZ0BXH4m.js";import{s as _}from"../chunks/B98B7x2v.js";import{p as h}from"../chunks/2qELrB5S.js";function B(r=!1){const e=g,t=e.l.u;if(!t)return;let a=()=>y(e.s);if(r){let o=0,s={};const f=E(()=>{let p=!1;const i=e.s;for(const n in i)i[n]!==s[n]&&(s[n]=i[n],p=!0);return p&&o++,o});a=()=>d(f)}t.b.length&&b(()=>{v(e,a),l(t.b)}),c(()=>{const o=x(()=>t.m.map(k));return()=>{for(const s of o)typeof s=="function"&&s()}}),t.a.length&&c(()=>{v(e,a),l(t.a)})}function v(r,e){if(r.l.s)for(const t of r.l.s)d(t);e()}var C=$("<h1> </h1> <p> </p>",1);function J(r,e){Z(e,!1),B();var t=C(),a=j(t),o=u(a,!0);m(a);var s=A(a,2),f=u(s,!0);m(s),q(()=>{_(o,h.status),_(f,h.error?.message)}),w(r,t),z()}export{J as component};
