svg.svelte-1joeiwq{font:9px sans-serif}.node.svelte-1joeiwq{cursor:row-resize}.node.svelte-1joeiwq rect:where(.svelte-1joeiwq){stroke:#000;stroke-width:2px}.link.svelte-1joeiwq{fill:none;stroke:#000;stroke-opacity:.3}.link.svelte-1joeiwq:hover{stroke-opacity:.5}.cycle-link.svelte-1joeiwq{opacity:.3;stroke:none;stroke-linejoin:round}.cycle-link.svelte-1joeiwq:hover{opacity:.5}
