import"./DsnmJJEf.js";import{p as k,b as y,e as _,r as u,a as c,i as R,m as f,h as U,v as S,g as t}from"./BZ0BXH4m.js";import{s as j}from"./B98B7x2v.js";import{e as q,i as w}from"./B9BLuPDP.js";import{r as z,s as p}from"./C5ruyaoV.js";import{d as A}from"./fIP5WTNy.js";import{b as B}from"./kHklRsBK.js";import{p as v}from"./CUAkeMiK.js";function C(m,a,i){a()(i())}var D=_('<div class="form-check form-check-inline"><input class="form-check-input" type="radio"/> <label class="form-check-label"> </label></div>'),E=_('<div role="radiogroup"></div>');function N(m,a){k(a,!0);const i=[];let l=v(a,"value",31,()=>y(a.options[0])),b=v(a,"disabled",3,!1),h=v(a,"onUpdate",3,()=>{});var s=E();q(s,21,()=>a.options,w,(g,r)=>{var o=D(),e=f(o);z(e),e.__change=[C,h,l];var n,d=U(e,2),x=f(d,!0);u(d),u(o),S(()=>{p(e,"id","radio-"+t(r).value),e.disabled=b(),n!==(n=t(r).value)&&(e.value=(e.__value=t(r).value)??""),p(d,"for","radio-"+t(r).value),j(x,t(r).label)}),B(i,[],e,()=>(t(r).value,l()),l),c(g,o)}),u(s),c(m,s),R()}A(["change"]);export{N as R};
