import{a as e}from"./BIpecMnu.js";import{q as s}from"./BZ0BXH4m.js";function p(r,o={},f,i){for(var t in f){var a=f[t];o[t]!==a&&(f[t]==null?r.style.removeProperty(t):r.style.setProperty(t,a,i))}}function A(r,o,f,i){var t=r.__style;if(s||t!==o){var a=e(o,i);(!s||a!==r.getAttribute("style"))&&(a==null?r.removeAttribute("style"):r.style.cssText=a),r.__style=o}else i&&(Array.isArray(i)?(p(r,f?.[0],i[0]),p(r,f?.[1],i[1],"important")):p(r,f,i));return i}export{A as s};
