import{D as c,q as f,E as _,F as d,G as l,B as u,H as h,I as m,n as v,J as y,K as o,L as g}from"./BZ0BXH4m.js";function b(r,n,...s){var t=r,e=v,a;c(()=>{e!==(e=n())&&(a&&(y(a),a=null),a=m(()=>e(t,...s)))},h),f&&(t=o)}function F(r){return(n,...s)=>{var t=r(...s),e;if(f)e=o,_();else{var a=t.render().trim(),p=d(a);e=g(p),n.before(e)}const i=t.setup?.(e);l(e,e),typeof i=="function"&&u(i)}}export{F as c,b as s};
