import{N as i,M as d,q as c,O as n,P as v,Q as u,R as h}from"./BZ0BXH4m.js";const l=Symbol("is custom element"),g=Symbol("is html");function p(r){if(c){var s=!1,e=()=>{if(!s){if(s=!0,r.hasAttribute("value")){var o=r.value;_(r,"value",null),r.value=o}if(r.hasAttribute("checked")){var a=r.checked;_(r,"checked",null),r.checked=a}}};r.__on_r=e,v(e),u()}}function _(r,s,e,o){var a=A(r);c&&(a[s]=r.getAttribute(s),s==="src"||s==="srcset"||s==="href"&&r.nodeName==="LINK")||a[s]!==(a[s]=e)&&(s==="loading"&&(r[h]=e),e==null?r.removeAttribute(s):typeof e!="string"&&N(r).includes(s)?r[s]=e:r.setAttribute(s,e))}function A(r){return r.__attributes??={[l]:r.nodeName.includes("-"),[g]:r.namespaceURI===i}}var f=new Map;function N(r){var s=f.get(r.nodeName);if(s)return s;f.set(r.nodeName,s=[]);for(var e,o=r,a=Element.prototype;a!==o;){e=n(o);for(var t in e)e[t].set&&s.push(t);o=d(o)}return s}export{p as r,_ as s};
