import"./DsnmJJEf.js";import{p as c,e as v,r as m,v as d,a as f,i as b,m as h,g as r}from"./BZ0BXH4m.js";import{s as g}from"./B98B7x2v.js";import{e as x,i as D}from"./B9BLuPDP.js";import{s as j}from"./C5ruyaoV.js";import{d as w}from"./fIP5WTNy.js";import{j as I}from"./B_jXps8r.js";import{p as n}from"./CUAkeMiK.js";function U(l,e,o){e.onUpdate?.(o())}var k=v("<option> </option>"),q=v('<select class="form-select"></select>');function H(l,e){c(e,!0);let o=n(e,"value",15),p=n(e,"disabled",3,!1);var a=q();a.__change=[U,e,o],x(a,21,()=>e.options,D,(u,s)=>{var t=k(),_=h(t,!0);m(t);var i={};d(()=>{g(_,r(s).label),i!==(i=r(s).value)&&(t.value=(t.__value=r(s).value)??"")}),f(u,t)}),m(a),d(()=>{j(a,"id",e.formId),a.disabled=p()}),I(a,o),f(l,a),b()}w(["change"]);export{H as D};
